@@ -1195,8 +1195,9 @@ def upload_callback():
     curdoc().add_next_tick_callback(load)
 
 
-def main():
+def main(doc):
     global Main_plot, path_, file_name, mycursor
+    print('curdoc:',curdoc(),'\ndoc:', doc)
     try: myconnect()
     except:
         try: creatbase()
@@ -1208,13 +1209,13 @@ def main():
     except:
         print('Please Choose your Extensions and Data paths\n')
         Error_remind = Div(text='Please Choose your Extensions and Data path...')
-        curdoc().add_root(Error_remind)
+        doc.add_root(Error_remind)
     
     '''upload_button = Button(label="Show")
     upload_button.on_event(ButtonClick, upload_callback)
     curdoc().add_root(upload_button) # 这就是那个按钮'''
 
-    curdoc().add_next_tick_callback(upload_callback)
+    doc.add_next_tick_callback(upload_callback)
 
     
 if __name__ == "main":
@@ -1249,4 +1250,4 @@ def fetch():
     for x in result:
         print(x)
     print("=== test finished ===")
-    return result[-2][0], result[-1][0]
+    return result[-2][0], result[-1][0]
\ No newline at end of file
